import { useEffect, useRef, useState } from "react";
import invokeMap from "lodash/fp/invokeMap";
import isNumber from "lodash/fp/isNumber";
import noop from "lodash/fp/noop";
import { defaultOpts } from "./debounce.types";
export var useDebounce = function (overrideOpts) {
    var opts = Object.assign(defaultOpts, isNumber(overrideOpts) ? { delay: overrideOpts } : overrideOpts);
    return function useDebounceInternal(fn) {
        var _a = useState(false), ready = _a[0], setReady = _a[1];
        var timeout = useRef(null);
        var wrapper = useRef(noop);
        var abort = useRef(noop);
        var terminate = useRef(noop);
        useEffect(function () {
            wrapper.current = function () {
                var params = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    params[_i] = arguments[_i];
                }
                if (opts.persist) {
                    invokeMap("persist", params);
                }
                var wrapper = function () {
                    fn.apply(void 0, params);
                    timeout.current = null;
                };
                abort.current = function () {
                    timeout.current && clearTimeout(timeout.current);
                    abort.current = noop;
                    terminate.current = noop;
                };
                terminate.current = function () {
                    if (timeout.current) {
                        clearTimeout(timeout.current);
                        terminate.current = noop;
                        abort.current = noop;
                        wrapper();
                    }
                };
                timeout.current && clearTimeout(timeout.current);
                timeout.current = setTimeout(wrapper, opts.delay);
            };
            setReady(true);
        }, [fn, ready]);
        return Object.assign(wrapper.current, {
            abort: function () { return abort.current(); },
            terminate: function () { return terminate.current(); },
        });
    };
};
export default useDebounce;
//# sourceMappingURL=debounce.js.map