export declare type Function = (...args: any[]) => void;
/**
 * Add debounce to a handler.
 *
 * @param   opts  Debounce options
 * @returns       The handler wrapped
 */
export declare type UseDebounce = (opts?: number | Partial<DebounceOpts>) => <T extends Function>(fn: T) => Debounce<T>;
export declare type DebounceOpts = {
    /**
     * Debounce delay before triggering the handler.
     *
     * @default 300
     */
    delay: number;
    /**
     * Should keep the original event by calling `.persist()`.
     *
     * @default false
     */
    persist: boolean;
};
export declare type Debounce<T extends Function> = {
    (...params: Parameters<T>): void;
    /**
     * Abort the debounce.
     */
    abort: () => void;
    /**
     * Abort the debounce and trigger immediatly the handler.
     */
    terminate: () => void;
};
export declare const defaultOpts: DebounceOpts;
