/// <reference types="node" />
export declare type Function = (...args: any[]) => void;
/**
 * Wrapper around `setTimeout`.
 *
 * @param   opts  Timeout options
 * @returns       The handler wrapped
 */
export declare type UseTimeout = (opts?: number | Partial<TimeoutOpts>) => <T extends Function>(fn: T) => Timeout<T>;
export declare type TimeoutOpts = {
    /**
     * Timeout delay before triggering the callback.
     *
     * @default 300
     */
    delay: number;
    /**
     * Should keep the original event by calling `.persist()`.
     *
     * @default false
     */
    persist: boolean;
};
export declare type Timeout<T extends Function> = {
    (...params: Parameters<T>): void;
    /**
     * Abort the debounce.
     */
    abort: () => void;
    /**
     * Abort the debounce and trigger immediatly the callback.
     */
    terminate: () => void;
};
export declare type TimeoutsMap = Map<string, [NodeJS.Timeout, () => void]>;
export declare const defaultOpts: TimeoutOpts;
